@@ -12,7 +12,8 @@
 #include "bjb-main-toolbar.h"
 #include "bjb-main-view.h"
 #include "bjb-note-view.h"
-
+#include "bjb-organize-dialog.h"
+#include "bjb-share.h"
 
 #define BIJIBEN_MAIN_WIN_TITLE N_("Notes")
 #define SAVE_GEOMETRY_ID_TIMEOUT 100 /* ms */
@@ -186,11 +187,98 @@ on_key_pressed_cb (GtkWidget *w, GdkEvent *event, gpointer user_data)
         }
       break;
 
+    default:
+      ;
   }
 
   return FALSE;
 }
 
+static void
+on_detach_window_cb (GSimpleAction *action,
+                     GVariant      *parameter,
+                     gpointer       user_data)
+{
+  BjbWindowBase *self = BJB_WINDOW_BASE (user_data);
+  BijiNoteObj   *note = bjb_window_base_get_note (self);
+
+  if (!note)
+    return;
+
+  bjb_window_base_switch_to (self, BJB_WINDOW_BASE_MAIN_VIEW);
+  bijiben_new_window_for_note (g_application_get_default (), note);
+}
+
+static void
+on_undo_cb (GSimpleAction *action,
+            GVariant      *parameter,
+            gpointer       user_data)
+{
+  BijiNoteObj *note = bjb_window_base_get_note (BJB_WINDOW_BASE (user_data));
+
+  if (!note)
+    return;
+
+  biji_webkit_editor_undo (BIJI_WEBKIT_EDITOR (biji_note_obj_get_editor (note)));
+}
+
+static void
+on_redo_cb (GSimpleAction *action,
+            GVariant      *parameter,
+            gpointer       user_data)
+{
+  BijiNoteObj *note = bjb_window_base_get_note (BJB_WINDOW_BASE (user_data));
+
+  if (!note)
+    return;
+
+  biji_webkit_editor_redo (BIJI_WEBKIT_EDITOR (biji_note_obj_get_editor (note)));
+}
+
+static void
+on_view_notebooks_cb (GSimpleAction *action,
+                      GVariant      *parameter,
+                      gpointer       user_data)
+{
+  BjbWindowBase *self = BJB_WINDOW_BASE (user_data);
+  BijiNoteObj *note = bjb_window_base_get_note (self);
+  g_autoptr (GList) list = NULL;
+
+  if (!note)
+    return;
+
+  list = g_list_append (list, note);
+  bjb_organize_dialog_new (GTK_WINDOW (self), list);
+}
+
+static void
+on_email_cb (GSimpleAction *action,
+             GVariant      *parameter,
+             gpointer       user_data)
+{
+  BijiNoteObj *note = bjb_window_base_get_note (BJB_WINDOW_BASE (user_data));
+
+  if (!note)
+    return;
+
+  on_email_note_callback (note);
+}
+
+static void
+on_trash_cb (GSimpleAction *action,
+             GVariant      *parameter,
+             gpointer       user_data)
+{
+  BijiNoteObj *note = bjb_window_base_get_note (BJB_WINDOW_BASE (user_data));
+
+  if (!note)
+    return;
+
+  /* Delete the note from notebook
+   * The deleted note will emit a signal. */
+  biji_item_trash (BIJI_ITEM (note));
+}
+
 static void
 bjb_window_base_save_geometry (BjbWindowBase *self)
 {
@@ -240,6 +328,14 @@ bjb_window_base_configure_event (GtkWidget         *widget,
                                                                            event);
 }
 
+static GActionEntry win_entries[] = {
+  { "detach-window", on_detach_window_cb, NULL, NULL, NULL },
+  { "undo", on_undo_cb, NULL, NULL, NULL },
+  { "redo", on_redo_cb, NULL, NULL, NULL },
+  { "view-notebooks", on_view_notebooks_cb, NULL, NULL, NULL },
+  { "email", on_email_cb, NULL, NULL, NULL },
+  { "trash", on_trash_cb, NULL, NULL, NULL },
+};
 
 /* Gobj */
 static void
@@ -249,6 +345,11 @@ bjb_window_base_constructed (GObject *obj)
 
   G_OBJECT_CLASS (bjb_window_base_parent_class)->constructed (obj);
 
+  g_action_map_add_action_entries (G_ACTION_MAP (self),
+                                   win_entries,
+                                   G_N_ELEMENTS (win_entries),
+                                   self);
+
   self->settings = bjb_app_get_settings ((gpointer) g_application_get_default ());
 
   gtk_window_set_position (GTK_WINDOW (self),GTK_WIN_POS_CENTER);
@@ -422,7 +523,9 @@ destroy_note_if_needed (BjbWindowBase *self)
   self->note = NULL;
 
   if (self->note_view && GTK_IS_WIDGET (self->note_view))
-    g_clear_pointer (&(self->note_view), gtk_widget_destroy);
+    gtk_widget_destroy (GTK_WIDGET (self->note_view));
+
+  self->note_view = NULL;
 }
 
 
